summaryrefslogtreecommitdiffstats
path: root/mountconfig
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 19:59:13 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 19:59:13 -0600
commitbc3f9ee966e23165115ac340a4dbfb64f8d0a518 (patch)
tree37684d09f09a20de750ab8640249339e99eb177c /mountconfig
parenta47cb223414ce05fd91a0dc46540b4e7ba43f469 (diff)
downloadtde-guidance-bc3f9ee966e23165115ac340a4dbfb64f8d0a518.tar.gz
tde-guidance-bc3f9ee966e23165115ac340a4dbfb64f8d0a518.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'mountconfig')
-rwxr-xr-xmountconfig/mountconfig.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/mountconfig/mountconfig.py b/mountconfig/mountconfig.py
index 7f120d7..6ddec47 100755
--- a/mountconfig/mountconfig.py
+++ b/mountconfig/mountconfig.py
@@ -3270,7 +3270,7 @@ class MountConfigApp(programbase):
pass
def aboutData(self):
# Return the KAboutData object which we created during initialisation.
return self.aboutdata
def buttons(self):
# Only supply a Help button. Other choices are Default and Apply.
@@ -3286,8 +3286,8 @@ def create_mountconfig(parent,name):
############################################################################
def MakeAboutData():
- aboutdata = KAboutData("mountconfig",programname,version,"Disk & Filesystem Configuration Tool",
- KAboutData.License_GPL, "Copyright (C) 2003-2007 Simon Edwards")
+ aboutdata = TDEAboutData("mountconfig",programname,version,"Disk & Filesystem Configuration Tool",
+ TDEAboutData.License_GPL, "Copyright (C) 2003-2007 Simon Edwards")
aboutdata.addAuthor("Simon Edwards","Developer","simon@simonzone.com",
"http://www.simonzone.com/software/guidance")
aboutdata.addAuthor("Sebastian Kügler","Developer","sebas@kde.org","http://vizZzion.org");
@@ -3270,7 +3270,7 @@ class MountConfigApp(programbase):
pass
def aboutData(self):
- # Return the KAboutData object which we created during initialisation.
+ # Return the TDEAboutData object which we created during initialisation.
return self.aboutdata
def buttons(self):